==> notolog-1.0.2-py3-none-any.whl: notolog/lexemes/ko/toolbar.py <==
# Korean lexemes toolbar.py
lexemes = {
    "actions_label_new_document": "새 문서",
    "actions_accessible_name_new_document": "새 문서",
    "actions_label_open": "열기",
    "actions_accessible_name_open": "문서 열기",
    "actions_label_save": "저장",
    "actions_accessible_name_save": "문서 저장",
    "actions_label_save_as": "다른 이름으로 저장",
    "actions_accessible_name_save_as": "문서 복사본 저장",
    "actions_label_sync": "동기화",
    "actions_accessible_name_sync": "문서를 외부 저장소와 동기화",
    "actions_label_edit": "편집",
    "actions_accessible_name_edit": "파일 편집",
    "actions_label_source": "소스",
    "actions_accessible_name_source": "소스 코드",
    "actions_label_encrypt": "암호화",
    "actions_accessible_name_encrypt": "파일 암호화",
    "actions_label_decrypt": "복호화",
    "actions_accessible_name_decrypt": "파일 복호화",
    "actions_label_bold": "굵게",
    "actions_accessible_name_bold": "굵은 텍스트 형식",
    "actions_label_italic": "기울임꼴",
    "actions_accessible_name_italic": "기울임꼴 텍스트 형식",
    "actions_label_underline": "밑줄",
    "actions_accessible_name_underline": "밑줄 텍스트 형식",
    "actions_label_strikethrough": "취소선",
    "actions_accessible_name_strikethrough": "취소선 텍스트 형식",
    "actions_label_blockquote": "인용구",
    "actions_accessible_name_blockquote": "인용구 텍스트 형식",
    "actions_label_color_picker": "색상 선택기",
    "actions_accessible_name_color_picker": "텍스트 색상 선택",
    "actions_label_ai_assistant": "AI 보조",
    "actions_accessible_name_ai_assistant": "AI 보조 실행",
    "actions_label_about": "정보",
    "actions_accessible_name_about": "앱 정보",
    "actions_label_exit": "종료",
    "actions_accessible_name_exit": "앱 종료",
    "actions_label_settings": "설정",
    "actions_accessible_name_settings": "앱 설정",

    "search_input_label": "검색",
    "search_input_placeholder_text": "문서 내 텍스트",
    "search_input_accessible_description": "검색 입력 필드",
    "search_buttons_label_clear": "검색 지우기",
    "search_buttons_accessible_name_clear": "검색 입력 필드 지우기",
    "search_buttons_label_prev": "이전 검색",
    "search_buttons_accessible_name_prev": "이전 검색 결과",
    "search_buttons_label_next": "다음 검색",
    "search_buttons_accessible_name_next": "다음 검색 결과",
    "search_case_sensitive_label": "대소문자 구분",
    "search_case_sensitive_tooltip": "대소문자 구분 검색",
}

==> notolog-1.0.7-py3-none-any.whl: notolog/lexemes/ko/toolbar.py <==
# Korean lexemes toolbar.py
lexemes = {
    "actions_label_new_document": "새 문서",
    "actions_accessible_name_new_document": "새 문서",
    "actions_label_open": "열기",
    "actions_accessible_name_open": "문서 열기",
    "actions_label_save": "저장",
    "actions_accessible_name_save": "문서 저장",
    "actions_label_save_as": "다른 이름으로 저장",
    "actions_accessible_name_save_as": "문서 복사본 저장",
    "actions_label_sync": "동기화",
    "actions_accessible_name_sync": "문서를 외부 저장소와 동기화",
    "actions_label_edit": "편집",
    "actions_accessible_name_edit": "파일 편집",
    "actions_label_source": "소스",
    "actions_accessible_name_source": "소스 코드",
    "actions_label_encrypt": "암호화",
    "actions_accessible_name_encrypt": "파일 암호화",
    "actions_label_decrypt": "복호화",
    "actions_accessible_name_decrypt": "파일 복호화",
    "actions_label_bold": "굵게",
    "actions_accessible_name_bold": "굵은 텍스트 형식",
    "actions_label_italic": "기울임꼴",
    "actions_accessible_name_italic": "기울임꼴 텍스트 형식",
    "actions_label_underline": "밑줄",
    "actions_accessible_name_underline": "밑줄 텍스트 형식",
    "actions_label_strikethrough": "취소선",
    "actions_accessible_name_strikethrough": "취소선 텍스트 형식",
    "actions_label_blockquote": "인용구",
    "actions_accessible_name_blockquote": "인용구 텍스트 형식",
    "actions_label_color_picker": "색상 선택기",
    "actions_accessible_name_color_picker": "텍스트 색상 선택",
    "actions_label_ai_assistant": "AI 보조",
    "actions_accessible_name_ai_assistant": "AI 보조 실행",
    "actions_label_about": "정보",
    "actions_accessible_name_about": "앱 정보",
    "actions_label_exit": "종료",
    "actions_accessible_name_exit": "앱 종료",
    "actions_label_settings": "설정",
    "actions_accessible_name_settings": "앱 설정",

    "search_input_label": "검색",
    "search_input_placeholder_text": "문서에서 텍스트 검색",
    "search_input_accessible_description": "검색 입력 필드",
    "search_buttons_label_clear": "검색 지우기",
    "search_buttons_accessible_name_clear": "검색 입력 필드 지우기",
    "search_buttons_label_prev": "이전 검색",
    "search_buttons_accessible_name_prev": "이전 검색 결과",
    "search_buttons_label_next": "다음 검색",
    "search_buttons_accessible_name_next": "다음 검색 결과",
    "search_case_sensitive_accessible_name": "대소문자 구분",
    "search_case_sensitive_tooltip": "대소문자 구분 검색",
}
